# jaxknife
JAX accelerated statistical error calculations via jackknife, bootstrap, etc.

[![A rectangular badge, half black half purple containing the text made at Code Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)

To install `jaxknife` from PyPi with Python 3.10:

> `pip install jaxknife`